@@ -4,8 +4,16 @@
 #' Given a detection function analysis, construct a density surface model (DSM)
 #' based on environmental covariates.
 #'
+#' The response can be one of the following:
+#' \tabular{ll}{
+#'              \code{N}, \code{abundance} \tab count in each segment\cr
+#'              \code{Nhat}, \code{abundance.est} \tab estimated abundance per segment, estimation is via a Horvitz-Thompson estimator. This should be used when there are covariates in the detection function.\cr
+#'              \code{presence} \tab interpret the data as presence/absence (reember to change the \code{family} argument to \code{binomial()}\cr
+#'              \code{D}, \code{density} \tab density per segment\cr
+#'  }
+#'
 #' @param formula formula for the surface. This should be a
-#'   valid \code{\link{glm}}/\code{\link{gam}}/code{\link{gamm}} formula.
+#'   valid \code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}} formula.
 #' @param ddf.obj result from call to \code{\link{ddf}} or \code{\link{ds}}.
 #   If \code{ddf.obj} is \code{NULL} then strip transects are assumed.
 #' @param segment.data segment data, see \code{\link{dsm-data}}.
@@ -14,23 +22,13 @@
 #'   \code{\link{gam}}/code{\link{gamm}}).
 #' @param convert.units value to alter length to width for calculation
 #'   of the offset.
-#' @param family response distribution (popular choices include
-#'   \code{\link{quasipoisson}}, \code{\link{Tweedie}} and \code{\link{negbin}}.
+#' @param family response distribution (popular choices include \code{\link{quasipoisson}}, \code{\link{Tweedie}} and \code{\link{negbin}}. Defaults to \code{quasipossion}.
 #' @param \dots anything else to be passed straight to \code{\link{gam}}.
-#' @param group should group abundance/density be modelled rather than
-#'  individual abundance/density? This effectively sets the \code{size} column
-#'  in \code{observation.data} to be 1.
-#' @param control the usual \code{control} argument for a \code{gam},
-#'  \code{keepData} must be \code{TRUE} or variance estimation will not work.
-#' @param availability an availability bias used to scale the counts/estimated 
-#'        counts by. If we have \code{N} animals in a segment, then 
-#'        \code{N/availability} will be entered into the model. Uncertainty in
-#'        the availability is not handled at present.
-#' @return a \code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}} object, with
-#'  an additional element, \code{ddf} which holds the detection function object.
-#' @param gamma parameter to \code{gam()} set to a value of 1.4 (from advice in
-#'   Wood (2006)) such that the \code{gam()} is inclined to not 'overfit.'.
-#'
+#' @param group should group abundance/density be modelled rather than individual abundance/density? This effectively sets the \code{size} column in \code{observation.data} to be 1.
+#' @param control the usual \code{control} argument for a \code{gam}, \code{keepData} must be \code{TRUE} or variance estimation will not work.
+#' @param availability an availability bias used to scale the counts/estimated  counts by. If we have \code{N} animals in a segment, then \code{N/availability} will be entered into the model. Uncertainty in the availability is not handled at present.
+#' @param gamma parameter to \code{gam()} set to a value of 1.4 (from advice in Wood (2006)) such that the \code{gam()} is inclined to not 'overfit.'.
+#' @return a \code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}} object, with an additional element, \code{ddf} which holds the detection function object.
 #' @author David L. Miller
 # @seealso
 #' @references Hedley, S. and S. T. Buckland. 2004. Spatial models for line transect sampling. JABES 9:181-199.
@@ -79,7 +77,9 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
 
   ## check the formula
   response <- as.character(formula)[2]
-  possible.responses <- c("D","density","N","Nhat","abundance","abundance.est")
+  possible.responses <- c("D","density",
+                          "N","Nhat","abundance","abundance.est",
+                          "presence")
   if(!(response %in% possible.responses)){
     stop(paste("Model must be one of:",
                paste(possible.responses,collapse=", ")))
@@ -87,7 +87,7 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
 
 
   # if we are not modelling density, then add in the offset
-  if(!(response %in% c("D","density"))){
+  if(!(response %in% c("D","density","presence"))){
     formula <- as.formula(paste(c(as.character(formula)[c(2,1,3)],
                                 "+ offset(off.set)"),collapse=""))
   }
@@ -102,6 +102,8 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
                control=control, ...), warning = matrixnotposdef.handler)
     fit$gamma <- gamma
   }else if(engine == "gamm"){
+    # unsupported
+    control$keepData <- NULL
     fit <- withCallingHandlers(gamm(formula,family=family, data=dat,
                                     gamma=gamma,control=control, ...),
                                warning = matrixnotposdef.handler)
@@ -113,7 +115,11 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
   }
 
   ## add the detection function object into the gam/gamm/glm object
-  fit$ddf <- ddf.obj
+  if(engine == "gamm"){
+    fit$gam$ddf <- ddf.obj
+  }else{
+    fit$ddf <- ddf.obj
+  }
 
   class(fit) <- c("dsm",class(fit))
 
